@@ -32,7 +32,10 @@ import (
 	"github.com/apache/skywalking-satellite/internal/satellite/event"
 )
 
-const Name = "nativecds-grpc-forwarder"
+const (
+	Name     = "nativecds-grpc-forwarder"
+	ShowName = "Native CDS GRPC Forwarder"
+)
 
 type Forwarder struct {
 	config.CommonFields
@@ -44,6 +47,10 @@ func (f *Forwarder) Name() string {
 	return Name
 }
 
+func (f *Forwarder) ShowName() string {
+	return ShowName
+}
+
 func (f *Forwarder) Description() string {
 	return "This is a synchronization grpc forwarder with the SkyWalking native Configuration Discovery Service protocol."
 }
