@@ -33,7 +33,10 @@ import (
 	v1 "skywalking.apache.org/repo/goapi/satellite/data/v1"
 )
 
-const Name = "nativeevent-grpc-forwarder"
+const (
+	Name     = "nativeevent-grpc-forwarder"
+	ShowName = "Native Event GRPC Forwarder"
+)
 
 type Forwarder struct {
 	config.CommonFields
@@ -44,6 +47,10 @@ func (f *Forwarder) Name() string {
 	return Name
 }
 
+func (f *Forwarder) ShowName() string {
+	return ShowName
+}
+
 func (f *Forwarder) Description() string {
 	return "This is a synchronization grpc forwarder with the SkyWalking native event protocol."
 }
