@@ -31,7 +31,10 @@ import (
 	"github.com/apache/skywalking-satellite/internal/satellite/event"
 )
 
-const Name = "nativejvm-grpc-forwarder"
+const (
+	Name     = "nativejvm-grpc-forwarder"
+	ShowName = "Native JVM GRPC Forwarder"
+)
 
 type Forwarder struct {
 	config.CommonFields
@@ -43,6 +46,10 @@ func (f *Forwarder) Name() string {
 	return Name
 }
 
+func (f *Forwarder) ShowName() string {
+	return ShowName
+}
+
 func (f *Forwarder) Description() string {
 	return "This is a synchronization grpc forwarder with the SkyWalking native Configuration Discovery Service protocol."
 }
